==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/enums/KnownSyslogDataSourceFacilityNames.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class KnownSyslogDataSourceFacilityNames(
    public val javaValue: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames,
) : ConvertibleToJava<com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames> {
    Auth(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Auth),
    Authpriv(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Authpriv),
    Cron(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Cron),
    Daemon(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Daemon),
    Kern(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Kern),
    Lpr(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Lpr),
    Mail(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Mail),
    Mark(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Mark),
    News(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.News),
    Syslog(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Syslog),
    User(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.User),
    Uucp(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Uucp),
    Local0(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local0),
    Local1(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local1),
    Local2(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local2),
    Local3(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local3),
    Local4(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local4),
    Local5(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local5),
    Local6(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local6),
    Local7(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local7),
    Asterisk(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Asterisk),
    ;

    override fun toJava(): com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames):
            KnownSyslogDataSourceFacilityNames =
            KnownSyslogDataSourceFacilityNames.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/insights/kotlin/enums/KnownSyslogDataSourceFacilityNames.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.insights.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

public enum class KnownSyslogDataSourceFacilityNames(
    public val javaValue: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames,
) : ConvertibleToJava<com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames> {
    Alert(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Alert),
    Audit(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Audit),
    Auth(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Auth),
    Authpriv(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Authpriv),
    Clock(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Clock),
    Cron(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Cron),
    Daemon(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Daemon),
    Ftp(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Ftp),
    Kern(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Kern),
    Lpr(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Lpr),
    Mail(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Mail),
    Mark(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Mark),
    News(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.News),
    Nopri(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Nopri),
    Ntp(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Ntp),
    Syslog(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Syslog),
    User(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.User),
    Uucp(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Uucp),
    Local0(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local0),
    Local1(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local1),
    Local2(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local2),
    Local3(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local3),
    Local4(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local4),
    Local5(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local5),
    Local6(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local6),
    Local7(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Local7),
    Asterisk(com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames.Asterisk),
    ;

    override fun toJava(): com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.insights.enums.KnownSyslogDataSourceFacilityNames):
            KnownSyslogDataSourceFacilityNames =
            KnownSyslogDataSourceFacilityNames.values().first { it.javaValue == javaType }
    }
}
